@@ -31,7 +31,6 @@ Ext.namespace('Zarafa.plugins.desktopnotifications.js');
  * Singleton class to provide a wrapper for HTML5 desktop notifications feature
  */
 Zarafa.plugins.desktopnotifications.js.DesktopNotification = (function() {
-	var notificationAPI = window.webkitNotifications || window.Notification;
 	var PERMISSION = ['granted', 'default', 'denied'];
 
 	return {
@@ -41,7 +40,7 @@ Zarafa.plugins.desktopnotifications.js.DesktopNotification = (function() {
 		 */
 		supports : function()
 		{
-			if(notificationAPI) {
+			if (window.Notification) {
 				return true;
 			}
 
@@ -54,21 +53,21 @@ Zarafa.plugins.desktopnotifications.js.DesktopNotification = (function() {
 		 */
 		hasPermission : function()
 		{
-			if(!this.supports()) {
+			if (!this.supports()) {
 				console.log('Browser doesn\'t support notifications');
 				return;
 			}
 
 			var permission = 'default';
-			if(Ext.isFunction(notificationAPI.checkPermission)) {
-				permission = PERMISSION[notificationAPI.checkPermission()];
-			} else if (Ext.isFunction(notificationAPI.permissionLevel)) {
-				permission = notificationAPI.permissionLevel();
-			} else if (notificationAPI.permission) {
-				permission = notificationAPI.permission;
+			if (Ext.isFunction(Notification.checkPermission)) {
+				permission = PERMISSION[Notification.checkPermission()];
+			} else if (Ext.isFunction(Notification.permissionLevel)) {
+				permission = Notification.permissionLevel();
+			} else if (Notification.permission) {
+				permission = Notification.permission;
 			}
 
-			if(permission === 'granted') {
+			if (permission === 'granted') {
 				return true;
 			}
 
@@ -84,7 +83,7 @@ Zarafa.plugins.desktopnotifications.js.DesktopNotification = (function() {
 		 */
 		authorize : function(callback)
 		{
-			if(!this.supports()) {
+			if (!this.supports()) {
 				console.log('Browser doesn\'t support notifications');
 				return;
 			}
@@ -92,15 +91,15 @@ Zarafa.plugins.desktopnotifications.js.DesktopNotification = (function() {
 			var callbackFn = Ext.isFunction(callback) ? function(perm) {
 				// chrome doesn't give us current permission level, so default to granted if permission level is passed
 				var permission = 'granted';
-				if(perm) {
+				if (perm) {
 					permission = perm;
 				}
 
 				callback.apply(this, [permission]);
 			} : Ext.emptyFn;
 
-			if (Ext.isFunction(notificationAPI.requestPermission)) {
-				notificationAPI.requestPermission(callbackFn);
+			if (Ext.isFunction(Notification.requestPermission)) {
+				Notification.requestPermission(callbackFn);
 			}
 		},
 
@@ -119,31 +118,23 @@ Zarafa.plugins.desktopnotifications.js.DesktopNotification = (function() {
 		 */
 		notify : function(title, options, handlers)
 		{
-			if(!this.supports()) {
+			if (!this.supports()) {
 				console.log('Browser doesn\'t support notifications');
 				return;
 			}
 
-			if(!this.hasPermission()) {
+			if (!this.hasPermission()) {
 				console.log('Permission is denied to show desktop notifications');
 				return;
 			}
 
-			var notification;
-// autoclose, handlers
-//https://code.google.com/p/chromium/issues/detail?id=29643
-			if(Ext.isFunction(notificationAPI.createNotification)) {
-				notification = notificationAPI.createNotification(options.icon, title, options.body);
-				notification.show();
-			} else {
-				notification = new notificationAPI(title, {
-					icon : options.icon,
-					body : options.body,
-					tag : options.tag
-				});
-			}
+			var notification = new Notification(title, {
+				icon : options.icon,
+				body : options.body,
+				requireInteraction: true
+			});
 
-			if(container.getSettingsModel().get('zarafa/v1/plugins/desktopnotifications/autohide_enable')) {
+			if (container.getSettingsModel().get('zarafa/v1/plugins/desktopnotifications/autohide_enable')) {
 				var sleepTime = container.getSettingsModel().get('zarafa/v1/plugins/desktopnotifications/autohide_time') * 1000;
 				notification.addEventListener("show", function () {
 					setTimeout(function () {
@@ -152,7 +143,7 @@ Zarafa.plugins.desktopnotifications.js.DesktopNotification = (function() {
 				});
 			}
 
-			if(handlers) {
+			if (handlers) {
 				for(var key in handlers) {
 					notification['on' + key] = handlers[key];
 				}
@@ -188,7 +179,7 @@ Zarafa.plugins.desktopnotifications.DesktopNotificationsPlugin = Ext.extend(Zara
 	 * @protected
 	 */
 	initPlugin : function()
-	{
+	{	
 		Zarafa.plugins.desktopnotifications.DesktopNotificationsPlugin.superclass.initPlugin.apply(this, arguments);
 
 		this.registerInsertionPoint('context.settings.categories', this.createSettingsCategory, this);
@@ -209,14 +200,17 @@ Zarafa.plugins.desktopnotifications.DesktopNotificationsPlugin = Ext.extend(Zara
 	}
 });
 
-Zarafa.onReady(function() {
-	container.registerPlugin(new Zarafa.core.PluginMetaData({
-		name : 'desktopnotifications',
-		displayName : dgettext('plugin_desktopnotifications', 'Desktop Notifications Plugin'),
-		about : Zarafa.plugins.desktopnotifications.ABOUT,
-		pluginConstructor : Zarafa.plugins.desktopnotifications.DesktopNotificationsPlugin
-	}));
-});
+// Don't load the plugin if browser is IE
+if (!Ext.isIE) {
+	Zarafa.onReady(function() {
+		container.registerPlugin(new Zarafa.core.PluginMetaData({
+			name : 'desktopnotifications',
+			displayName : dgettext('plugin_desktopnotifications', 'Desktop Notifications Plugin'),
+			about : Zarafa.plugins.desktopnotifications.ABOUT,
+			pluginConstructor : Zarafa.plugins.desktopnotifications.DesktopNotificationsPlugin
+		}));
+	});
+}
 Ext.namespace('Zarafa.plugins.desktopnotifications.js');
 
 /**
@@ -365,7 +359,7 @@ Zarafa.plugins.desktopnotifications.js.settings.SettingsNotificationsWidget = Ex
 			items : [{
 				xtype : 'displayfield',
 				hideLabel : true,
-				value : dgettext('plugin_desktopnotifications', 'For enabling desktop notifications we need permissions from the browser. (Only Chrome and Firefox are supported)')
+				value : dgettext('plugin_desktopnotifications', 'We need permissions to enable desktop notifications.')
 			}, {
 				xtype : 'button',
 				width : 200,
@@ -440,7 +434,7 @@ Zarafa.plugins.desktopnotifications.js.settings.SettingsNotificationsWidget = Ex
 	requestPermission : function()
 	{
 		Zarafa.plugins.desktopnotifications.js.DesktopNotification.authorize(function(perm) {
-			if(perm === 'granted') {
+			if (perm === 'granted') {
 				// update ui
 				this.update(this.model);
 			}
@@ -452,19 +446,19 @@ Zarafa.plugins.desktopnotifications.js.settings.SettingsNotificationsWidget = Ex
 	 */
 	onChangeCheckbox : function(checkbox, checked)
 	{
-		if(!this.model) {
+		if (!this.model) {
 			return;
 		}
 
-		var type = 'popup';
+		var notifier = container.getSettingsModel().get(checkbox.name, false, true) || 'popup';
 
-		if(checked) {
-			type = 'desktopnotifier';
+		if (checked) {
+			notifier = 'desktopnotifier';
 		}
 
 		// change setting for new mail/reminder notification
-		if (this.model.get(checkbox.name) !== type) {
-			this.model.set(checkbox.name, type);
+		if (this.model.get(checkbox.name) !== notifier) {
+			this.model.set(checkbox.name, notifier);
 		}
 
 		// update ui
@@ -503,7 +497,7 @@ Zarafa.plugins.desktopnotifications.js.settings.SettingsNotificationsWidget = Ex
 		this.autoHideBox.setValue(enabled);
 
 		var spinnerValue = this.model.get(this.autoHideTimeSpinner.name);
-		if(spinnerValue === 0 || !Ext.isDefined(spinnerValue))  {
+		if (spinnerValue === 0 || !Ext.isDefined(spinnerValue))  {
 			this.autoHideTimeSpinner.setValue(5); // Default 5 minutes
 		} else {
 			this.autoHideTimeSpinner.setValue(spinnerValue);
@@ -519,7 +513,7 @@ Zarafa.plugins.desktopnotifications.js.settings.SettingsNotificationsWidget = Ex
 	updateSettings : function(settingsModel)
 	{
 		var spinnerValue = this.autoHideTimeSpinner.getValue();
-		if(spinnerValue === 0 || !Ext.isDefined(spinnerValue))  {
+		if (spinnerValue === 0 || !Ext.isDefined(spinnerValue))  {
 			spinnerValue = 1;
 		}
 
