@@ -5,11 +5,6 @@
  */
 class Plugindesktopnotifications extends Plugin {
 
-	/**
-	 * Constructor
-	 */
-	function Plugindesktopnotifications() {}
-
 	/**
 	 * Function initializes the Plugin and registers all hooks
 	 */
@@ -51,4 +46,4 @@ class Plugindesktopnotifications extends Plugin {
 		));
 	}
 }
-?>
\ No newline at end of file
+?>
