@@ -37,6 +37,22 @@ Zarafa.widgets.folderwidgets.AbstractFolderWidget = Ext.extend(Zarafa.core.ui.wi
 	 */
 	folderType: undefined,
 
+	/**
+	 * The task that was {@link Ext.TaskMgr.start started} to reload the folder grid.
+	 * @property
+	 * @type Object
+	 * @private
+	 */
+	reloadTask: undefined,
+
+	/**
+	 * The configuration object for the configure window of the widget
+	 * @property
+	 * @type Object
+	 * @private
+	 */
+	configurationConfig: undefined,
+
 	/**
 	 * @constructor
 	 * @param {Object} config Configuration object
@@ -45,8 +61,12 @@ Zarafa.widgets.folderwidgets.AbstractFolderWidget = Ext.extend(Zarafa.core.ui.wi
 	{
 		config = config || {};
 
+		// Set the guid so we can use the get() function
+		this.guid = config.guid;
+
 		Ext.applyIf(config, {
-			hasConfig: true
+			hasConfig: true,
+			height: this.get('widgetheight') || 300
 		});
 
 		Zarafa.widgets.folderwidgets.AbstractFolderWidget.superclass.constructor.call(this, config);
@@ -68,7 +88,10 @@ Zarafa.widgets.folderwidgets.AbstractFolderWidget = Ext.extend(Zarafa.core.ui.wi
 
 		// Wait for the store to be loaded, so we can activate
 		// the refreshing and reloading times.
-		this.mon(this.store, 'load', this.onStoreLoad, this, {single: true});
+		this.mon(this.store, 'load', this.startReloadTask, this, {single: true});
+
+		// Apply the filter when we have new records
+		this.mon(this.store, 'load', this.updateFilter, this);
 
 		// Listen for record updates, as that might have impact on the filtering
 		// which should be applied.
@@ -89,18 +112,22 @@ Zarafa.widgets.folderwidgets.AbstractFolderWidget = Ext.extend(Zarafa.core.ui.wi
 	},
 
 	/**
-	 * When the store has finished loading, update the filter for the first time.
+	 * Starts a reload task for the store. If one already exists, it will be stopped first.
 	 * @private
 	 */
-	onStoreLoad: function ()
+	startReloadTask: function ()
 	{
+		if ( this.reloadTask ) {
+			Ext.TaskMgr.stop(this.reloadTask);
+		}
+
 		// Periodically reload data from the server to remove stale
 		// data from the store.  But only do this when the store has
 		// finished loading for the first time.
 		var interval = this.get('reloadinterval') || 300;
 		interval *= 1000; // convert seconds in milliseconds
 
-		Ext.TaskMgr.start({
+		this.reloadTask = Ext.TaskMgr.start({
 			run: this.reloadStore,
 			interval: interval,
 			scope: this
@@ -135,30 +162,37 @@ Zarafa.widgets.folderwidgets.AbstractFolderWidget = Ext.extend(Zarafa.core.ui.wi
 	updateFilter: Ext.emptyFn,
 
 	/**
-	 * Helper function called when applying custom style and content for the
-	 * row-body.
-	 * Renders colored boxes per category with the first letter of the
-	 * category and its full name in a tooltip.
+	 * Apply custom style and content for the row body. This will color
+	 * a task in red when its due-date is reached. If categories are applied
+	 * to a task these categories will be displayed.
 	 *
 	 * @param {Ext.data.Record} record The {@link Ext.data.Record Record} corresponding to the current row.
-	 * @return {String} the colored boxes in HTML-format
+	 * @param {Number} rowIndex The row index
+	 * @param {Object} rowParams A config object that is passed to the row template during
+	 * rendering that allows customization of various aspects of a grid row.
+	 * If enableRowBody is configured true, then the following properties may be set by this function,
+	 * and will be used to render a full-width expansion row below each grid row.
+	 * @return {String} a CSS class name to add to the row
 	 * @private
 	 */
-	renderCategories: function (record)
+	viewConfigGetRowClass: function (record, rowIndex, rowParams)
 	{
-		var valueCategories = ''; // will contain list of categories as colored squares
+		rowParams.body = '<div class="zarafa-grid-body-container">';
 
+		// Render the categories
 		var categories = Zarafa.common.categories.Util.getCategories(record);
-		categories.forEach(function (category, i) {
-			var letter = category.substring(0, 1);
-			var color = Zarafa.common.categories.Util.getCategoryColor(category);
-			valueCategories = '<span class="advanced-folderwidget-category-box" style="background-color: ' + color + '" title="' + Ext.util.Format.htmlEncode(category) + '">' + Ext.util.Format.htmlEncode(letter) + '</span>';
-		});
+		var categoriesHtml = Zarafa.common.categories.Util.getCategoriesHtml(categories);
+		rowParams.body += '<div class="k-category-container">' + categoriesHtml + '</div>';
 
-		// Add an '|' as separator if list of categories is not empty
-		var separator = valueCategories ? " | " : "";
+		// Render the subject
+		var subject = Zarafa.common.ui.grid.Renderers.subject(record.get('subject'), {});
+		rowParams.body += String.format('<div class="grid_compact grid_compact_left grid_compact_subject_cell">{0}</div>', subject);
+		rowParams.body += '</div>';
 
-		return valueCategories + separator;
+		// Get the due date class from the normal TaskGridView
+		var rowClass = Zarafa.task.ui.TaskGridView.prototype.viewConfigGetRowClass(record);
+
+		return "x-grid3-row-expanded " + rowClass;
 	},
 
 	/**
@@ -195,11 +229,11 @@ Zarafa.widgets.folderwidgets.AbstractFolderWidget = Ext.extend(Zarafa.core.ui.wi
 	 */
 	config: function ()
 	{
-		var win = new Ext.Window({
+		var config = Ext.apply({}, this.configurationConfig || {}, {
 			title: _('Configure widget'),
 			layout: 'fit',
 			width: 320,
-			height: 130,
+			height: 135,
 			modal: true,
 			items: [{
 				xtype: 'form',
@@ -223,24 +257,35 @@ Zarafa.widgets.folderwidgets.AbstractFolderWidget = Ext.extend(Zarafa.core.ui.wi
 					plugins: ['zarafa.numberspinner']
 				},
 					this.createConfigHeight()
-				],
+				].concat(this.getConfigurationItems()),
 				buttons: [{
 					text: _('Close'),
 					scope: this,
 					handler: function () {
-						win.close();
+						this.win.close();
 					}
 				}]
 			}]
 		});
 
-		win.show(this);
+		this.win = new Ext.Window(config);
+		this.win.show(this);
+	},
+
+	/**
+	 * Returns an array with the items that should be added to the configuration window
+	 * of the widget. Should be overridden by child classes.
+	 * @return {array} An array of configuration objects for {@link Ext.Component components}
+	 */
+	getConfigurationItems: function()
+	{
+		return [];
 	},
 
 	/**
 	 * Event handler which is fired when one of the fields in the Configuration dialog
 	 * has been changed. This will update the corresponding option in the settings.
-	 * @param {Ext.form.Field} field The field whcih fired the event
+	 * @param {Ext.form.Field} field The field which fired the event
 	 * @param {Mixed} newValue The new value which was applied
 	 * @param {Mixed} oldValue The old value which was applied
 	 * @private
@@ -248,11 +293,15 @@ Zarafa.widgets.folderwidgets.AbstractFolderWidget = Ext.extend(Zarafa.core.ui.wi
 	onFieldChange: function (field, newValue, oldValue)
 	{
 		var fieldName = field.getName();
-
 		this.set(fieldName, newValue);
+
 		if (fieldName === 'widgetheight') {
 			this.setHeight(newValue);
 		}
+
+		if (fieldName === 'reloadinterval') {
+			this.startReloadTask();
+		}
 	}
 });
 Ext.namespace('Zarafa.widgets.folderwidgets');
@@ -285,24 +334,24 @@ Zarafa.widgets.folderwidgets.AppointmentsWidget = Ext.extend(Zarafa.widgets.fold
 		var store = new Zarafa.calendar.AppointmentStore();
 
 		Ext.applyIf(config, {
-			height: this.get('widgetheight') || 300,
 			autoScroll: true,
 			layout: 'fit',
 			folderType: 'calendar',
 			store: store,
 			items: [{
 				xtype: 'zarafa.gridpanel',
+				cls: 'k-appointmentwidget',
 				store: store,
 				hideHeaders: true,
 				loadMask: {
-					msg: _('Loading appointments') + '...'
+					msg: _('Loading appointments...')
 				},
-				sm: new Ext.grid.RowSelectionModel({
+				sm: new Zarafa.common.ui.grid.RowSelectionModel({
 					singleSelect: true
 				}),
 				viewConfig: {
 					deferEmptyText: false,
-					emptyText: '<div class="emptytext">' + _('No appointments for today.') + '</div>',
+					emptyText: '<div class="emptytext">' + _('No appointments') + '</div>',
 					forceFit: true,
 					enableRowBody: true,
 					rowSelectorDepth: 15,
@@ -313,7 +362,8 @@ Zarafa.widgets.folderwidgets.AppointmentsWidget = Ext.extend(Zarafa.widgets.fold
 					columns: [{
 						header: _('Time'),
 						dataIndex: 'startdate',
-						renderer: this.dummyColumnRenderer
+						renderer: this.timeRenderer,
+						scope: this
 					}]
 				}),
 				listeners: {
@@ -324,9 +374,79 @@ Zarafa.widgets.folderwidgets.AppointmentsWidget = Ext.extend(Zarafa.widgets.fold
 			}]
 		});
 
+		// Customize the configuration of the settings window
+		this.configurationConfig = {
+			height: 180
+		};
+
 		Zarafa.widgets.folderwidgets.AppointmentsWidget.superclass.constructor.call(this, config);
 	},
 
+	/**
+	 * Adds a field to configure the number of days for which appointments will be shown
+	 * @return {array} An array of configuration objects for {@link Ext.Component components}
+	 */
+	getConfigurationItems: function()
+	{
+		return [{
+			xtype: 'zarafa.spinnerfield',
+			fieldLabel: _('Number of days'),
+			name: 'numdays',
+			boxLabel: _('day(s)'),
+			width: 60,
+			minValue: 1, // 1 day
+			maxValue: 365, // 1 year
+			incrementValue: 1, // 1 day
+			defaultValue: this.get('numdays') || 5,
+			listeners: {
+				'change': this.onNumDaysChange,
+				scope: this
+			},
+			plugins: ['zarafa.numberspinner']
+		}];
+	},
+
+	/**
+	 * Event handler which is fired when 'Number of Days' field in the Configuration dialog
+	 * has been changed. This will update the corresponding option in the settings.
+	 * @param {Ext.form.Field} field The field which fired the event
+	 * @param {Mixed} newValue The new value which was applied
+	 * @param {Mixed} oldValue The old value which was applied
+	 * @private
+	 */
+	onNumDaysChange: function (field, newValue, oldValue)
+	{
+		this.set(field.getName(), newValue);
+		this.reloadStore();
+	},
+
+	/**
+	 * Initialize the event handlers for the {@link #store} and {@link Zarafa.hierarchy.data.HierarchyStore Hierarchy}.
+	 * @protected
+	 */
+	initEvents: function ()
+	{
+		Zarafa.widgets.folderwidgets.AppointmentsWidget.superclass.initEvents.apply(this, arguments);
+
+		// Wait for the store to be loaded, so we can activate
+		// the filter task.
+		this.mon(this.store, 'load', this.startFilterTask, this, {single: true});
+	},
+
+	/**
+	* Starts a filter task for the store. Will make sure that the filter is updated at
+	* every 30 seconds so old appointments will be filtered out.
+	* @private
+	*/
+	startFilterTask: function ()
+	{
+		Ext.TaskMgr.start({
+			run: this.updateFilter,
+			interval: 30000,
+			scope: this
+		});
+	},
+
 	/**
 	 * This will {@link Ext.data.Store#load load} the {@link #store} using
 	 * a restriction which only allows todays appointments.
@@ -334,240 +454,90 @@ Zarafa.widgets.folderwidgets.AppointmentsWidget = Ext.extend(Zarafa.widgets.fold
 	 */
 	reloadStore: function ()
 	{
-		if (this.folder) {
-			var now = new Date();
-			var today = now.clearTime();
-			var dueDate = today.add(Date.DAY, 10);
-
-			this.store.load({
-				folder: this.folder,
-				params: {
-					restriction: {
-						startdate: now.getTime() / 1000,
-						// FIXME: Create Config-Option for duedate
-						duedate: dueDate.getTime() / 1000,
-						// FIXME: Create Config-Option for limit
-						limit: 10
-					}
-				}
-			});
+		if (!this.folder) {
+			return;
 		}
+
+		var numDays = this.get('numdays') || 5;
+
+		var startdate = new Date().clearTime().getTime() / 1000;
+		var duedate = new Date().clearTime().add(Date.DAY, numDays).getTime() / 1000;
+
+		this.store.load({
+			folder: this.folder,
+			params: {
+				restriction: {
+					startdate: startdate,
+					duedate: duedate
+				}
+			}
+		});
 	},
 
 	/**
-	 * Update the filter with the current time.  Items that end
+	 * Update the filter with the current time. Items that end
 	 * before now are removed.
 	 * @private
 	 */
 	updateFilter: function ()
 	{
+		var now = new Date().getTime() / 1000;
 		this.store.filterBy(function (record) {
-			var now = new Date();
-			var startdate = record.get('startdate') || now;
-			var duedate = record.get('duedate') || now;
-			return (startdate >= now || duedate >= now) && startdate < now.clearTime().add(Date.DAY, 1);
+			var dueDate = record.get('duedate').getTime() / 1000;
+			return !dueDate || dueDate >= now;
 		}, this);
 	},
 
 	/**
-	 * Just needed to make sure the 'columns'-object renders a line with height=0px
+	 * Renderer for the time column. Adds a recurrence icon and a private icon if applicable
 	 *
 	 * @param {Mixed} value The subject of the appointment
 	 * @param {Object} metaData Used to set style information to gray out appointments that occur now
 	 * @param {Ext.data.Record} record The record being displayed, used to retrieve the start and end times
 	 * @private
 	 */
-	dummyColumnRenderer: function (value, metaData, record)
+	timeRenderer: function (value, metaData, record)
 	{
-		metaData.attr = "style='padding:0; margin:0; height:0px; '";
-		return "";
-	},
-
-	/**
-	 * Apply custom style and content for the row body. This will color
-	 * a task in red when its due-date is reached. If categories are applied
-	 * to an appointment these categories will be displayed in a colored square naming
-	 * the first letter of the category and its full name in a tooltip.
-	 *
-	 * @param {Ext.data.Record} record The {@link Ext.data.Record Record} corresponding to the current row.
-	 * @param {Number} rowIndex The row index
-	 * @param {Object} rowParams A config object that is passed to the row template during
-	 * rendering that allows customization of various aspects of a grid row.
-	 * If enableRowBody is configured true, then the following properties may be set by this function,
-	 * and will be used to render a full-width expansion row below each grid row.
-	 * @param {Ext.data.Store} store The Ext.data.Store this grid is bound to
-	 * @return {String} a CSS class name to add to the row
-	 * @private
-	 */
-	viewConfigGetRowClass: function (record, rowIndex, rowParams)
-	{
-
-		var iconToString = function (icon) {
-			return '<img src="' + icon.src + '" /> ';
-		};
-
-		var value = '<table width="100%"><tbody>';
-
-		/**
-		 * this.startdateArray is used to simulate some "grouping" in the table
-		 * as 'this' is not in the context of this class, the array has to be
-		 * initialized here.
-		 */
-		if (!this.startdateArray) {
-			this.startdateArray = new Array();
-		}
-
-		var recordDate = record.get("startdate");
-		var todaysDate = new Date;
-
-		this.startdateArray[rowIndex] = recordDate;
-
-		if ((!this.startdateArray[rowIndex - 1]) || (this.startdateArray[rowIndex - 1].add(Date.DAY, 1).clearTime() <= recordDate)) {
-			// the appointment before was on another day then this appointment
-
-			value += '<tr><td><div class="folderwidget-groupedview">';
-
-			if (recordDate <= todaysDate.add(Date.DAY, 1).clearTime()) {
-				value += _("Today");
-			} else if (recordDate < todaysDate.add(Date.DAY, 2).clearTime()) {
-				value += _("Tomorrow");
-			} else if (recordDate <= todaysDate.add(Date.DAY, 7).clearTime()) {
-				value += recordDate.format('l');
-			} else {
-				value += recordDate.format(_("d.m.Y"));
-			}
-
-			value += '</div></td></tr>';
-		}
-
-		// Row to display time + recurrance + location
-		value += '<tr><td>';
-
-		if (record.get('alldayevent')) {
-			value += _('All Day');
-		} else {
-			value += record.get("startdate").format(_("G:i")) + ' - ' + record.get("duedate").format(_("G:i"));
-		}
-
+		var recurringIcon = '';
 		var recurringPattern = record.get('recurring_pattern');
 		if (recurringPattern) {
 			if (record.get('exception') === true) {
-				value += ' <span title="' + recurringPattern + '">' + iconToString(Zarafa.calendar.ui.IconCache.getExceptionIcon()) + '</span>';
+				recurringIcon =
+					'&nbsp;<span ext:qwidth="300" ext:qtip="' + recurringPattern + '">' +
+						'<img src="' + Zarafa.calendar.ui.IconCache.getExceptionIcon().src + '"/>' +
+					'</span>';
 			} else {
-				value += ' <span title="' + recurringPattern + '">' + iconToString(Zarafa.calendar.ui.IconCache.getRecurringIcon()) + '</span>';
+				recurringIcon =
+					'&nbsp;<span ext:qwidth="300" ext:qtip="' + recurringPattern + '">' +
+						'<img src="' + Zarafa.calendar.ui.IconCache.getRecurringIcon().src + '"/>' +
+					'</span>';
 			}
 		}
 
-		// Row to display categories + subject + private-flag
-		value += '</td></tr><tr><td>';
-
-		value += Zarafa.widgets.folderwidgets.AppointmentsWidget.superclass.renderCategories(record);
-
-		value += record.get("subject");
-
+		var privateIcon = '';
 		if (record.get('private') === true) {
-			value += ' ' + iconToString(Zarafa.calendar.ui.IconCache.getPrivateIcon());
+			privateIcon = '&nbsp;<img src="' + Zarafa.calendar.ui.IconCache.getPrivateIcon().src + '"/>';
 		}
 
-		value += '</td></tr></tbody></table>';
+		var dayStart = new Date().clearTime();
+		var dayEnd = new Date().add(Date.DAY, 1).clearTime();
+		var start = value;
+		var end = record.get('duedate');
+		var allDayEvent = record.get('alldayevent');
 
-		rowParams.body = value;
-
-		return "x-grid3-row-expanded ";
-	},
-
-	/**
-	 * Render the subject, which is the time span + the subject of
-	 * the appointment.  The passed value is the subject of the
-	 * appointment, the rest of the data is retrieved through record.
-	 *
-	 * @param {Mixed} value The subject of the appointment
-	 * @param {Object} metaData Used to set style information to gray out appointments that occur now
-	 * @param {Ext.data.Record} record The record being displayed, used to retrieve the start and end times
-	 * @param {Number} rowIndex The index of the rendered row
-	 * @param {Number} colIndex The index of the rendered column
-	 * @param {Ext.data.Store} store The store to which the record belongs
-	 * @private
-	 */
-	subjectRenderer : function(value, metaData, record, rowIndex, colIndex, store) {
-			var now = new Date();
-			// # TRANSLATORS: See http://docs.sencha.com/ext-js/3-4/#!/api/Date for the meaning of these formatting instructions
-			var starttime = (record.get('startdate') || now).format(_("G:i"));
-			// # TRANSLATORS: See http://docs.sencha.com/ext-js/3-4/#!/api/Date for the meaning of these formatting instructions
-			var duetime = (record.get('duedate') || now).format(_("G:i"));
-			if ((record.get('startdate') || now) < now) {
-				metaData.attr = "style='color: #888; font-weight: bold;'";
-			} else {
-				metaData.attr = "style='font-weight: bold;'";
+		if ( start >= dayStart && end <= dayEnd ) {
+			if ( !allDayEvent ) {
+				return String.format(_('Today {0} - {1}'), start.format(_('G:i')), end.format(_('G:i'))) + recurringIcon + privateIcon;
 			}
 
-			var icons = '';
-			var iconToString = function(icon) { return '<img src="' + icon.src + '" /> '; };
-
-			if (record.get('private') === true) {
-				icons += iconToString(Zarafa.calendar.ui.IconCache.getPrivateIcon());
-			}
-			if (record.get('recurring') === true) {
-				if (record.get('exception') === true) {
-					icons += iconToString(Zarafa.calendar.ui.IconCache.getExceptionIcon());
-				} else {
-					icons += iconToString(Zarafa.calendar.ui.IconCache.getRecurringIcon());
-				}
-			}
-
-			if (record.get('alldayevent')) {
-				// # TRANSLATORS: {0} is the subject of an all-day
-				// # appointment, {1} is the html code to display
-				// # icons.
-				return String.format(_("Today: {1} {0}"), Ext.util.Format.htmlEncode(value), icons);
-			}
-
-			return String.format("{1}-{2}: {3} {0}", Ext.util.Format.htmlEncode(value), starttime, duetime, icons);
-	},
-
-	/**
-	 * Add additional information to the row, in this case the location of
-	 * the meeting.
-	 * TODO: add a preview of the body here.
-	 * The location is rendered in its own table for future use.
-	 *
-	 * @param record The record being displayed.  If it has no
-	 * location set, then the table is omitted entirely.
-	 * @param {Number} rowIndex The index of the rendered row
-	 * @param {Object} rowParams The row parameters
-	 * @param {Ext.data.Store} store The store in which the record is placed
-	 * @returns A string containing a space separated list of css
-	 * classes to apply.  It will always contain 'today-item', and a
-	 * second class that indicates the intended busy state of the
-	 * appointment.
-	 * @private
-	 */
-	applyRowClass: function (record, rowIndex, rowParams, store)
-	{
-		var location = record.get('location');
-		if (location) {
-			rowParams.body = '<table style="width: 100%; padding: 0; border-spacing: 0;">';
-			rowParams.body += String.format('<tr><td style="width: 100%; font-size: 80%;"><i>{0}</i></td></tr>',
-				Ext.util.Format.htmlEncode(location));
-			rowParams.body += '</table>';
-		} else {
-			rowParams.body = '';
+			return _('Today (all day)') + recurringIcon + privateIcon;
 		}
 
-		var css = 'today-item ';
-		var busystatus = record.get('busystatus');
-		switch (busystatus) {
-			case Zarafa.core.mapi.BusyStatus.FREE:
-				return css + 'today-free';
-			case Zarafa.core.mapi.BusyStatus.TENTATIVE:
-				return css + 'today-tentative';
-			case Zarafa.core.mapi.BusyStatus.BUSY:
-				return css + 'today-busy';
-			case Zarafa.core.mapi.BusyStatus.OUTOFOFFICE:
-				return css + 'today-outofoffice';
-			default:
-				return css + 'today-unknown';
+		if ( !allDayEvent ) {
+			return String.format(_('{0} - {1}'), start.format(_('d/m/y G:i')), end.format(_('d/m/y G:i'))) + recurringIcon + privateIcon;
 		}
+
+		return String.format(_('{0} - {1} (all day)'), start.format(_('d/m/y')), end.format(_('d/m/y'))) + recurringIcon + privateIcon;
 	},
 
 	/**
@@ -622,7 +592,7 @@ Zarafa.widgets.folderwidgets.AppointmentsWidget = Ext.extend(Zarafa.widgets.fold
 Zarafa.onReady(function () {
 	container.registerWidget(new Zarafa.core.ui.widget.WidgetMetaData({
 		name : 'appointments',
-		displayName : _('Today\'s Appointments'),
+		displayName : _('Upcoming Appointments'),
 		widgetConstructor : Zarafa.widgets.folderwidgets.AppointmentsWidget
 	}));
 });
@@ -755,7 +725,6 @@ Zarafa.widgets.folderwidgets.MailWidget = Ext.extend(Zarafa.widgets.folderwidget
 		};
 
 		Ext.applyIf(config, {
-			height : 200,
 			autoScroll: true,
 			layout: 'fit',
 			folderType : 'inbox',
@@ -768,7 +737,7 @@ Zarafa.widgets.folderwidgets.MailWidget = Ext.extend(Zarafa.widgets.folderwidget
 				loadMask : {
 					msg : _('Loading mail') + '...'
 				},
-				sm: new Ext.grid.RowSelectionModel({
+				sm: new Zarafa.common.ui.grid.RowSelectionModel({
 					singleSelect: true
 				}),
 				viewConfig: {
@@ -936,28 +905,33 @@ Zarafa.widgets.folderwidgets.TasksWidget = Ext.extend(Zarafa.widgets.folderwidge
 		store.setDefaultSort('duedate', 'asc');
 
 		// Create a restriction, we only want uncomplete tasks, so tasks which
-		// do not have the status flag set to Zarafa.core.mapi.TaskStatus.COMPLETE
+		// do not have the status flag set to Zarafa.core.mapi.TaskStatus.COMPLETE or
+		// Zarafa.core.mapi.FlagStatus.completed
 		store.setRestriction({
-			'task': Zarafa.core.data.RestrictionFactory.dataResProperty(
+			'task': Zarafa.core.data.RestrictionFactory.createResAnd([Zarafa.core.data.RestrictionFactory.dataResProperty(
 				'status',
 				Zarafa.core.mapi.Restrictions.RELOP_NE,
 				Zarafa.core.mapi.TaskStatus.COMPLETE
-			)
+			),Zarafa.core.data.RestrictionFactory.dataResProperty(
+				'flag_status',
+				Zarafa.core.mapi.Restrictions.RELOP_NE,
+				Zarafa.core.mapi.FlagStatus.completed
+			)])
 		});
 
 		Ext.applyIf(config, {
-			height: this.get('widgetheight') || 300,
 			autoScroll: true,
 			layout: 'fit',
 			folderType: 'todolist',
 			store: store,
 			items: [{
 				xtype: 'zarafa.gridpanel',
+				cls: 'k-taskwidget',
 				store: store,
 				loadMask: {
 					msg: _('Loading tasks') + '...'
 				},
-				sm: new Ext.grid.RowSelectionModel({
+				sm: new Zarafa.common.ui.grid.RowSelectionModel({
 					singleSelect: true
 				}),
 				viewConfig: {
@@ -971,27 +945,26 @@ Zarafa.widgets.folderwidgets.TasksWidget = Ext.extend(Zarafa.widgets.folderwidge
 				},
 				colModel: new Ext.grid.ColumnModel({
 					columns: [{
-						header: _("Due Date"),
-						tooltip: _("Due Date"),
+						header: _("Due"),
+						tooltip : _('Sort by: Due Date'),
 						dataIndex: "duedate",
-						renderer: this.dueDateRenderer
+						renderer: Zarafa.common.ui.grid.Renderers.utcdate
 					}, {
 						header: "<p class='icon_importance'>&nbsp;</p>",
-						tooltip: _("Importance"),
+						tooltip : _('Sort by: Priority'),
 						dataIndex: "importance",
-						align: "center",
-						width: 55,
+						width: 24,
+						fixed: true,
 						renderer: Zarafa.common.ui.grid.Renderers.importance
 					}, {
 						header: "%",
-						tooltip: _("% Completed"),
+						tooltip : _('Sort by: Percentage Completed'),
 						dataIndex: "percent_complete",
-						align: "center",
-						width: 80,
+						width : 75,
 						renderer: Zarafa.common.ui.grid.Renderers.percentage
 					}, {
 						header: _('Owner'),
-						tooltip: _("Owner"),
+						tooltip : _('Sort by: Owner'),
 						dataIndex: 'owner',
 						renderer: this.ownerRenderer
 					}],
@@ -1022,35 +995,6 @@ Zarafa.widgets.folderwidgets.TasksWidget = Ext.extend(Zarafa.widgets.folderwidge
 		}, this);
 	},
 
-	/**
-	 * Render the due date in the form "d/m/Y" and add color red if
-	 * due date is already reached
-	 *
-	 * @param {Mixed} value The subject of the appointment
-	 * @param {Object} metaData Used to set style information to gray out appointments that occur now
-	 * @param {Ext.data.Record} record The record being displayed, used to retrieve the start and end times
-	 * @private
-	 */
-	dueDateRenderer: function (value, metaData, record)
-	{
-		var dateNow = new Date();
-		var dateDue = record.get("duedate");
-		metaData.attr = "";
-
-		if (!dateDue) {
-			value = _("none");
-		} else if (dateDue < dateNow.clearTime().add(Date.DAY, 1)) {
-			value = _("Today");
-			metaData.attr = "style='color: #F00;'";
-		} else if (dateDue < dateNow.clearTime().add(Date.DAY, 2)) {
-			value = _("Tomorrow");
-		} else {
-			value = dateDue.format(_("d/m/Y"));
-		}
-
-		return String.format("{0}", value);
-	},
-
 	/**
 	 * Renders the owner of the task as its initials and adds its full
 	 * form as a tooltip
@@ -1074,41 +1018,7 @@ Zarafa.widgets.folderwidgets.TasksWidget = Ext.extend(Zarafa.widgets.folderwidge
 			initials += ownerNames[i].substring(0, 1);
 		}
 
-		return '<span title="' + Ext.util.Format.htmlEncode(owner) + '">' + Ext.util.Format.htmlEncode(initials) + '</span>';
-	},
-
-	/**
-	 * Apply custom style and content for the row body. This will color
-	 * a task in red when its due-date is reached. If categories are applied
-	 * to a task these categories will be displayed in a colored square naming
-	 * the first letter of the category and its full name in a tooltip.
-	 *
-	 * @param {Ext.data.Record} record The {@link Ext.data.Record Record} corresponding to the current row.
-	 * @param {Number} rowIndex The row index
-	 * @param {Object} rowParams A config object that is passed to the row template during
-	 * rendering that allows customization of various aspects of a grid row.
-	 * If enableRowBody is configured true, then the following properties may be set by this function,
-	 * and will be used to render a full-width expansion row below each grid row.
-	 * @return {String} a CSS class name to add to the row
-	 * @private
-	 */
-	viewConfigGetRowClass: function (record, rowIndex, rowParams)
-	{
-		var valueSubject = record.get("subject"); // Subject to be displayed
-		var valueCategories = Zarafa.widgets.folderwidgets.TasksWidget.superclass.renderCategories(record);
-
-		// Add color red if due date is reached
-		var dateNow = new Date();
-		var dateDue = record.get("duedate");
-		var color = "";
-
-		if (dateDue && (dateDue < dateNow.clearTime().add(Date.DAY, 1))) {
-			color = 'style="color:#F00;"';
-		}
-
-		rowParams.body = String.format('<div class="folderwidget-task-row" {2}>{1}{0}</div>', valueSubject, valueCategories, color);
-
-		return "x-grid3-row-expanded ";
+		return '<span ext:qtip="' + Ext.util.Format.htmlEncode(owner) + '" ext:qwidth="100%">' + Ext.util.Format.htmlEncode(initials) + '</span>';
 	},
 
 	/**
@@ -1156,7 +1066,7 @@ Zarafa.widgets.folderwidgets.TasksWidget = Ext.extend(Zarafa.widgets.folderwidge
 Zarafa.onReady(function () {
 	container.registerWidget(new Zarafa.core.ui.widget.WidgetMetaData({
 		name : 'tasks',
-		displayName : _('Tasks'),
+		displayName : _('Tasks / To-Do'),
 		widgetConstructor : Zarafa.widgets.folderwidgets.TasksWidget
 	}));
 });
