@@ -771,6 +771,9 @@ define('PR_EC_OUTOFOFFICE_SUBJECT'                    ,mapi_prop_tag(PT_STRING8,
 define('PR_EC_OUTOFOFFICE_FROM'                       ,mapi_prop_tag(PT_SYSTIME,     PR_EC_BASE+0x63));
 define('PR_EC_OUTOFOFFICE_UNTIL'                         ,mapi_prop_tag(PT_SYSTIME,     PR_EC_BASE+0x64));
 
+/* Server version */
+define('PR_EC_SERVER_VERSION'                        ,mapi_prop_tag(PT_STRING8,     PR_EC_BASE+0x16));
+
 /* quota support */
 define('PR_QUOTA_WARNING_THRESHOLD'                   ,mapi_prop_tag(PT_LONG,        PR_EC_BASE+0x21));
 define('PR_QUOTA_SEND_THRESHOLD'                      ,mapi_prop_tag(PT_LONG,        PR_EC_BASE+0x22));
@@ -805,6 +808,7 @@ define('PR_EC_COMPANY_NAME', mapi_prop_tag(PT_STRING8,	PR_EC_BASE+0x48));
 
 /* WA properties */
 define('PR_EC_WA_ATTACHMENT_HIDDEN_OVERRIDE', mapi_prop_tag(PT_BOOLEAN, PR_EC_BASE+0xE0));
+define('PR_EC_WA_ATTACHMENT_ID', mapi_prop_tag(PT_STRING8, PR_EC_BASE+0xE1));
 
 // edkmdb, rules properties
 #define pidSpecialMin                                   0x6670
@@ -901,6 +905,12 @@ define('PR_WLINK_RECKEY'                     ,mapi_prop_tag(PT_BINARY,     0x684
 define('PR_WB_SF_ID'                         ,mapi_prop_tag(PT_BINARY,     0x6842));
 
 /* Search folder properties */
-define('PR_EC_SUGGESTION'					,mapi_prop_tag(PT_TSTRING, 0x6707));
+define('PR_EC_SUGGESTION'                    ,mapi_prop_tag(PT_TSTRING, 0x6707));
 
+define('PR_EC_BODY_FILTERED'                 ,mapi_prop_tag(PT_BINARY, 0x6791));
+define('PR_EC_ENABLED_FEATURES'              ,mapi_prop_tag(PT_MV_TSTRING, PR_EC_BASE+0xB3));
+define('PR_EC_DISABLED_FEATURES'             ,mapi_prop_tag(PT_MV_TSTRING, 0x67B4));
+
+define('PR_PROPOSEDNEWTIME_START', PR_PROPOSENEWTIME_START);
+define('PR_PROPOSEDNEWTIME_END', PR_PROPOSENEWTIME_END);
 ?>
