@@ -43,11 +43,11 @@
 		var $searchResults;
 
 		/**
-		 * @var MAPIFolder resource of the freebusy folder which holds
+		 * @var MAPIMessage resource of the freebusy message which holds
 		 * information regarding delegation details, this variable will
 		 * only be populated when user is a delegate
 		 */
-		var $localFreeBusyFolder;
+		var $localFreeBusyMessage;
 
 		/**
 		 * @var BinString binary string of PR_MDB_PROVIDER property
@@ -66,7 +66,7 @@
 
 			$this->restriction = false;
 			$this->searchFolderList = false;
-			$this->localFreeBusyFolder = false;
+			$this->localFreeBusyMessage = false;
 			$this->storeProviderGuid = false;
 
 			$this->sort = array();
@@ -183,15 +183,7 @@
 					}
 				}
 
-				// Disable private items
-				for($index = 0, $len = count($data["item"]); $index < $len; $index++) {
-					$data["item"][$index] = $this->processPrivateItem($data["item"][$index]);
-
-					if(empty($data["item"][$index])) {
-						// remove empty results from data
-						unset($data["item"][$index]);
-					}
-				}
+				$data = $this->filterPrivateItems($data);
 
 				// Allowing to hook in just before the data sent away to be sent to the client
 				$GLOBALS['PluginManager']->triggerHook('server.module.listmodule.list.after', array(
@@ -259,7 +251,6 @@
 				// When searching in the To-do list we will actually always search in the IPM subtree, so
 				// set the entryid to that.
 		        $userStore = WebAppAuthentication::getMapiSession()->getDefaultMessageStore();
-		        $root = mapi_msgstore_openentry($userStore, null);
 		        $props = mapi_getprops($userStore, array(PR_IPM_SUBTREE_ENTRYID));
 		        $entryid = $props[PR_IPM_SUBTREE_ENTRYID];
 			}
@@ -371,6 +362,9 @@
 			$table = $GLOBALS["operations"]->getTable($store, hex2bin($searchFolderEntryId), $this->properties, $this->sort, $this->start);
 			$data = array_merge($data, $table);
 
+			$this->getDelegateFolderInfo($store);
+			$data = $this->filterPrivateItems($data);
+
 			// remember which entryid's are send to the client
 			$searchResults = array();
 			foreach($table["item"] as $item) {
@@ -729,6 +723,7 @@
 								$props = array_merge($this->properties, array('body' => PR_BODY));
 							case "task":
 							case "note":
+							case "filter":
 								$this->restriction = Conversion::json2restriction($props, $value);
 								break;
 						}
@@ -809,13 +804,13 @@
 		}
 
 		/**
-		 * Function which gets the delegation details from localfreebusy folder to use in
+		 * Function which gets the delegation details from localfreebusy message to use in
 		 * processPrivateItems function.
 		 * @param {MAPIStore} $store MAPI Message Store Object
 		 */
 		function getDelegateFolderInfo($store)
 		{
-			$this->localFreeBusyFolder = false;
+			$this->localFreeBusyMessage = false;
 			$this->storeProviderGuid = false;
 
 			try {
@@ -827,28 +822,38 @@
 					return;
 				}
 
-				// open localfreebusy folder for delegate permissions
-				$rootFolder = mapi_msgstore_openentry($store, null);
-				$rootFolderProps = mapi_getprops($rootFolder, array(PR_FREEBUSY_ENTRYIDS));
-
-				/**
-				 *	PR_FREEBUSY_ENTRYIDS contains 4 entryids
-				 *	PR_FREEBUSY_ENTRYIDS[0] gives associated freebusy folder in calendar
-				 *	PR_FREEBUSY_ENTRYIDS[1] Localfreebusy (used for delegate properties)
-				 *	PR_FREEBUSY_ENTRYIDS[2] global Freebusydata in public store
-				 *	PR_FREEBUSY_ENTRYIDS[3] Freebusydata in IPM_SUBTREE
-				 */
-				// get localfreebusy folder
-				$this->localFreeBusyFolder = mapi_msgstore_openentry($store, $rootFolderProps[PR_FREEBUSY_ENTRYIDS][1]);
+				// get localfreebusy message
+				$this->localFreeBusyMessage = freebusy::getLocalFreeBusyMessage($store);
 			} catch(MAPIException $e) {
 				// we got some error, but we don't care about that error instead just continue
 				$e->setHandled();
 
-				$this->localFreeBusyFolder = false;
+				$this->localFreeBusyMessage = false;
 				$this->storeProviderGuid = false;
 			}
 		}
 
+		/**
+		 * Helper function which loop through each item and filter out
+		 * private items, if any.
+		 * @param {array} array structure with row search data
+		 * @return {array} array structure with row search data
+		 */
+		function filterPrivateItems($data)
+		{
+			// Disable private items
+			for($index = 0, $len = count($data["item"]); $index < $len; $index++) {
+				$data["item"][$index] = $this->processPrivateItem($data["item"][$index]);
+
+				if(empty($data["item"][$index])) {
+					// remove empty results from data
+					unset($data["item"][$index]);
+				}
+			}
+
+			return $data;
+		}
+
 		/**
 		 * Function will be used to process private items in a list response, modules can
 		 * can decide what to do with the private items, remove the entire row or just
@@ -891,21 +896,21 @@
 					$private = true;
 
 					// find delegate properties
-					if($this->localFreeBusyFolder !== false) {
+					if($this->localFreeBusyMessage !== false) {
 						try {
-							$localFreeBusyFolderProps = mapi_getprops($this->localFreeBusyFolder, array(PR_SCHDINFO_DELEGATE_ENTRYIDS, PR_DELEGATES_SEE_PRIVATE));
+							$localFreeBusyMessageProps = mapi_getprops($this->localFreeBusyMessage, array(PR_SCHDINFO_DELEGATE_ENTRYIDS, PR_DELEGATES_SEE_PRIVATE));
 
-							if(isset($localFreeBusyFolderProps[PR_SCHDINFO_DELEGATE_ENTRYIDS]) && isset($localFreeBusyFolderProps[PR_DELEGATES_SEE_PRIVATE])) {
+							if(isset($localFreeBusyMessageProps[PR_SCHDINFO_DELEGATE_ENTRYIDS]) && isset($localFreeBusyMessageProps[PR_DELEGATES_SEE_PRIVATE])) {
 								// if more then one delegates info is stored then find index of
 								// current user
 								$userEntryId = $GLOBALS['mapisession']->getUserEntryID();
 
 								$userFound = false;
 								$seePrivate = false;
-								foreach($localFreeBusyFolderProps[PR_SCHDINFO_DELEGATE_ENTRYIDS] as $key => $entryId) {
+								foreach($localFreeBusyMessageProps[PR_SCHDINFO_DELEGATE_ENTRYIDS] as $key => $entryId) {
 									if ($GLOBALS['entryid']->compareABEntryIds(bin2hex($userEntryId), bin2hex($entryId))) {
 										$userFound = true;
-										$seePrivate = $localFreeBusyFolderProps[PR_DELEGATES_SEE_PRIVATE][$key];
+										$seePrivate = $localFreeBusyMessageProps[PR_DELEGATES_SEE_PRIVATE][$key];
 										break;
 									}
 								}
